@@ -6,16 +6,19 @@ from .base import Flow
 
 
 class Radial(Flow):
-    """
-    Radial flow as introduced in arXiv: 1505.05770
+    """Radial flow as introduced in [arXiv: 1505.05770](https://arxiv.org/abs/1505.05770)
+
+    ```
         f(z) = z + beta * h(alpha, r) * (z - z_0)
+    ```
     """
 
     def __init__(self, shape, z_0=None):
-        """
-        Constructor of the radial flow
-        :param shape: shape of the latent variable z
-        :param z_0: parameter of the radial flow
+        """Constructor of the radial flow
+
+        Args:
+          shape: shape of the latent variable z
+          z_0: parameter of the radial flow
         """
         super().__init__()
         self.d_cpu = torch.prod(torch.tensor(shape))
@@ -34,9 +37,10 @@ class Radial(Flow):
     def forward(self, z):
         beta = torch.log(1 + torch.exp(self.beta)) - torch.abs(self.alpha)
         dz = z - self.z_0
-        r = torch.norm(dz, dim=list(range(1, self.z_0.dim())))
+        r = torch.linalg.vector_norm(dz, dim=list(range(1, self.z_0.dim())), keepdim=True)
         h_arr = beta / (torch.abs(self.alpha) + r)
         h_arr_ = -beta * r / (torch.abs(self.alpha) + r) ** 2
-        z_ = z + h_arr.unsqueeze(1) * dz
+        z_ = z + h_arr * dz
         log_det = (self.d - 1) * torch.log(1 + h_arr) + torch.log(1 + h_arr + h_arr_)
+        log_det = log_det.reshape(-1)
         return z_, log_det
