@@ -12,10 +12,7 @@ from itertools import repeat
 
 
 class LipschitzMLP(nn.Module):
-    """
-    Fully connected neural net which is Lipschitz continuous
-    with Lipschitz constant L < 1
-    """
+    """Fully connected neural net which is Lipschitz continuou with Lipschitz constant L < 1"""
 
     def __init__(
         self,
@@ -27,15 +24,15 @@ class LipschitzMLP(nn.Module):
     ):
         """
         Constructor
-        :param channels: Integer list with the number of channels of
+          channels: Integer list with the number of channels of
         the layers
-        :param lipschitz_const: Maximum Lipschitz constant of each layer
-        :param max_lipschitz_iter: Maximum number of iterations used to
+          lipschitz_const: Maximum Lipschitz constant of each layer
+          max_lipschitz_iter: Maximum number of iterations used to
         ensure that layers are Lipschitz continuous with L smaller than
         set maximum; if None, tolerance is used
-        :param lipschitz_tolerance: Float, tolerance used to ensure
+          lipschitz_tolerance: Float, tolerance used to ensure
         Lipschitz continuity if max_lipschitz_iter is None, typically 1e-3
-        :param init_zeros: Flag, whether to initialize last layer
+          init_zeros: Flag, whether to initialize last layer
         approximately with zeros
         """
         super().__init__()
@@ -85,19 +82,15 @@ class LipschitzCNN(nn.Module):
         lipschitz_tolerance=None,
         init_zeros=True,
     ):
-        """
-        Constructor
-        :param channels: Integer list with the number of channels of
-        the layers
-        :param kernel_size: Integer list of kernel sizes of the layers
-        :param lipschitz_const: Maximum Lipschitz constant of each layer
-        :param max_lipschitz_iter: Maximum number of iterations used to
-        ensure that layers are Lipschitz continuous with L smaller than
-        set maximum; if None, tolerance is used
-        :param lipschitz_tolerance: Float, tolerance used to ensure
-        Lipschitz continuity if max_lipschitz_iter is None, typically 1e-3
-        :param init_zeros: Flag, whether to initialize last layer
-        approximately with zeros
+        """Constructor
+
+        Args:
+          channels: Integer list with the number of channels of the layers
+          kernel_size: Integer list of kernel sizes of the layers
+          lipschitz_const: Maximum Lipschitz constant of each layer
+          max_lipschitz_iter: Maximum number of iterations used to ensure that layers are Lipschitz continuous with L smaller than set maximum; if None, tolerance is used
+          lipschitz_tolerance: Float, tolerance used to ensure Lipschitz continuity if max_lipschitz_iter is None, typically 1e-3
+          init_zeros: Flag, whether to initialize last layer approximately with zeros
         """
         super().__init__()
 
@@ -126,7 +119,7 @@ class LipschitzCNN(nn.Module):
                     n_iterations=max_lipschitz_iter,
                     atol=lipschitz_tolerance,
                     rtol=lipschitz_tolerance,
-                    zero_init=init_zeros if i == self.n_layers - 1 else False,
+                    zero_init=init_zeros if i == (self.n_layers - 1) else False,
                 ),
             ]
 
@@ -314,6 +307,7 @@ class InducedNormConv2d(nn.Module):
         n_iterations=None,
         atol=None,
         rtol=None,
+        zero_init=False,
         **unused_kwargs
     ):
         del unused_kwargs
@@ -336,7 +330,7 @@ class InducedNormConv2d(nn.Module):
             self.bias = nn.Parameter(torch.Tensor(out_channels))
         else:
             self.register_parameter("bias", None)
-        self.reset_parameters()
+        self.reset_parameters(zero_init)
         self.register_buffer("initialized", torch.tensor(0))
         self.register_buffer("spatial_dims", torch.tensor([1.0, 1.0]))
         self.register_buffer("scale", torch.tensor(0.0))
@@ -351,8 +345,11 @@ class InducedNormConv2d(nn.Module):
             domain, codomain = self.domain, self.codomain
         return domain, codomain
 
-    def reset_parameters(self):
+    def reset_parameters(self, zero_init=False):
         init.kaiming_uniform_(self.weight, a=math.sqrt(5))
+        if zero_init:
+            # normalize cannot handle zero weight in some cases.
+            self.weight.data.div_(1000)
         if self.bias is not None:
             fan_in, _ = init._calculate_fan_in_and_fan_out(self.weight)
             bound = 1 / math.sqrt(fan_in)
